==> apache-uniffle-0.8.0-incubating-src.tar.gz: apache-uniffle-0.8.0-incubating-src/coordinator/src/main/java/org/apache/uniffle/coordinator/web/Response.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.coordinator.web;

public class Response<T> {
  private static final int SUCCESS_CODE = 0;
  private static final int ERROR_CODE = -1;
  private int code;
  private T data;
  private String errMsg;

  public Response() {}

  public Response(int code, T data, String errMsg) {
    this.code = code;
    this.data = data;
    this.errMsg = errMsg;
  }

  public static <T> Response<T> success(T data) {
    return new Response<>(SUCCESS_CODE, data, null);
  }

  public static <T> Response<T> fail(String msg) {
    return new Response<>(ERROR_CODE, null, msg);
  }

  public static <T> Response<T> fail(String msg, int code) {
    return new Response<>(code, null, msg);
  }

  public int getCode() {
    return code;
  }

  public void setCode(int code) {
    this.code = code;
  }

  public T getData() {
    return data;
  }

  public void setData(T data) {
    this.data = data;
  }

  public String getErrMsg() {
    return errMsg;
  }

  public void setErrMsg(String errMsg) {
    this.errMsg = errMsg;
  }
}

==> apache-uniffle-0.9.2-incubating-src.tar.gz: apache-uniffle-0.9.2-incubating-src/coordinator/src/main/java/org/apache/uniffle/coordinator/web/Response.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.coordinator.web;

public class Response<T> {
  private static final int SUCCESS_CODE = 0;
  private static final int ERROR_CODE = -1;
  private int code;
  private T data;
  private String msg;

  public Response() {}

  public Response(int code, T data, String msg) {
    this.code = code;
    this.data = data;
    this.msg = msg;
  }

  public static <T> Response<T> success(T data) {
    return new Response<>(SUCCESS_CODE, data, "success");
  }

  public static <T> Response<T> fail(String msg) {
    return new Response<>(ERROR_CODE, null, msg);
  }

  public static <T> Response<T> fail(String msg, int code) {
    return new Response<>(code, null, msg);
  }

  public int getCode() {
    return code;
  }

  public void setCode(int code) {
    this.code = code;
  }

  public T getData() {
    return data;
  }

  public void setData(T data) {
    this.data = data;
  }

  public String getErrMsg() {
    return msg;
  }

  public void setErrMsg(String errMsg) {
    this.msg = errMsg;
  }
}
